#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_Blend_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_BrightnessContrast_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_ColorOverlay_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_Colorize_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_ConicalGradient_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_Desaturate_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_DirectionalBlur_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_Displace_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_DropShadow_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_FastBlur_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_GammaAdjust_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_GaussianBlur_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_Glow_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_HueSaturation_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_InnerShadow_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_LevelAdjust_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_LinearGradient_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_MaskedBlur_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_OpacityMask_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_RadialBlur_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_RadialGradient_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_RectangularGlow_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_RecursiveBlur_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_ThresholdMask_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_ZoomBlur_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/Blend.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_Blend_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/BrightnessContrast.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_BrightnessContrast_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/ColorOverlay.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_ColorOverlay_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/Colorize.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_Colorize_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/ConicalGradient.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_ConicalGradient_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/Desaturate.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_Desaturate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/DirectionalBlur.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_DirectionalBlur_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/Displace.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_Displace_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/DropShadow.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_DropShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/FastBlur.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_FastBlur_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/GammaAdjust.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_GammaAdjust_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/GaussianBlur.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_GaussianBlur_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/Glow.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_Glow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/HueSaturation.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_HueSaturation_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/InnerShadow.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_InnerShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/LevelAdjust.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_LevelAdjust_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/LinearGradient.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_LinearGradient_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/MaskedBlur.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_MaskedBlur_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/OpacityMask.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_OpacityMask_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/RadialBlur.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_RadialBlur_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/RadialGradient.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_RadialGradient_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/RectangularGlow.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_RectangularGlow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/RecursiveBlur.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_RecursiveBlur_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/ThresholdMask.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_ThresholdMask_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt-project.org/imports/Qt5Compat/GraphicalEffects/ZoomBlur.qml"), &QmlCacheGeneratedCode::_qt_0x2d_project_0x2e_org_imports_Qt5Compat_GraphicalEffects_ZoomBlur_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_qtgraphicaleffectsplugin)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_qtgraphicaleffectsplugin))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_qtgraphicaleffectsplugin)() {
    return 1;
}
