/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<qgfxshaderbuilder_p.h>)
#  include <qgfxshaderbuilder_p.h>
#endif
#if __has_include(<qgfxsourceproxy_p.h>)
#  include <qgfxsourceproxy_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_Qt5Compat_GraphicalEffects_private()
{
    qmlRegisterModule("Qt5Compat.GraphicalEffects.private", 1, 0);
    qmlRegisterModule("Qt5Compat.GraphicalEffects.private", 1, 254);
    qmlRegisterModule("Qt5Compat.GraphicalEffects.private", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QGfxShaderBuilder>("Qt5Compat.GraphicalEffects.private", 6);
    qmlRegisterTypesAndRevisions<QGfxSourceProxy>("Qt5Compat.GraphicalEffects.private", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuickItem>("Qt5Compat.GraphicalEffects.private", 6);
    qmlRegisterEnum<QGfxSourceProxy::Interpolation>("QGfxSourceProxy::Interpolation");
    QT_WARNING_POP
    qmlRegisterModule("Qt5Compat.GraphicalEffects.private", 6, 12);
}

static const QQmlModuleRegistration qt5CompatGraphicalEffectsprivateRegistration("Qt5Compat.GraphicalEffects.private", qml_register_types_Qt5Compat_GraphicalEffects_private);
