/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.12.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0xc,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xb3,0x6,0x15,0x10,0x0,0x16,0xd7,0x43,0x1e,0x30,0x73,0x1b,
  0x33,0x43,0x49,0x22,0x51,0x46,0xa0,0x64,0x21,0xad,0x87,0x58,0xf5,0xf7,0xa6,0xfb,
  0x7f,0xe6,0x21,0x2a,0x3f,0x2a,0x83,0x41,0x4d,0x94,0xa,0x3c,0x0,0x3e,0x0,0x39,
  0x0,0xfb,0xee,0xde,0x8b,0xd0,0xb7,0x2b,0x86,0xcb,0x22,0x97,0x36,0x84,0xda,0xa8,
  0x28,0x6a,0xda,0x8e,0xff,0x39,0xa8,0xb9,0x8a,0xed,0x6d,0xf5,0x1b,0x2,0x61,0xf0,
  0x5b,0xb9,0xbe,0xa6,0xb9,0x41,0xf0,0xa9,0xc5,0x60,0x12,0x4d,0x29,0xb6,0x9e,0xfa,
  0x42,0x7a,0x7d,0x97,0x3b,0x8,0x5e,0x12,0x6d,0x8b,0xcc,0x5d,0x1,0x15,0x7b,0x46,
  0x1,0x69,0x10,0xb1,0xde,0x66,0x80,0xa6,0x69,0x82,0xef,0xee,0x5d,0x3c,0x55,0xee,
  0xa4,0xa7,0x36,0xe3,0xfc,0x1,0x7e,0x33,0x11,0x22,0x5f,0xcc,0xfa,0x83,0x3a,0x8e,
  0x35,0x5b,0x24,0xd,0xc5,0x51,0xb2,0xaf,0x1c,0xf6,0x27,0x41,0xd6,0xfb,0x96,0x41,
  0xb0,0x5d,0x1b,0xc9,0x61,0x9a,0xf7,0x79,0x1e,0x62,0x1,0x31,0x63,0x86,0x15,0xf4,
  0xba,0x74,0x91,0xf,0x55,0x91,0x1d,0xc7,0xd4,0xa2,0x3c,0xe7,0x49,0x69,0x7b,0x30,
  0x3d,0x36,0x3,0xb5,0xce,0xf9,0xea,0xf1,0x15,0x2e,0x22,0xbf,0x97,0x99,0xfa,0xa2,
  0x73,0x3f,0x9c,0x1e,0x6d,0xbe,0x1c,0x88,0xbb,0xe6,0xe,0xf9,0x50,0xfd,0xdb,0x1d,
  0x20,0xdc,0x7e,0x2b,0x10,0x94,0x97,0x73,0x97,0x64,0xcd,0x59,0x70,0xdd,0xaa,0xe4,
  0x72,0x18,0x7a,0x4c,0xd7,0x16,0xab,0xd6,0xa7,0x36,0x93,0x99,0x4e,0xd2,0xf3,0x4c,
  0xe9,0x83,0x24,0x5b,0xd,0xd4,0x47,0xba,0x6e,0x73,0xb6,0xe5,0xac,0x23,0x7d,0xbb,
  0x1b,0xd9,0x8e,0x29,0x1b,0x19,0xd9,0xb2,0x95,0x21,0xc,0x77,0xa8,0xd1,0xc5,0x40,
  0x6a,0x46,0xa3,0x42,0x69,0x5a,0x3,0x90,0x24,0x10,0x84,0xdb,0x1c,0x21,0x10,0x3,
  0x32,0x86,0x19,0x65,0x90,0x22,0x85,0x88,0xc4,0x24,0xcd,0x1,0xa6,0xd6,0xd0,0xe9,
  0x6d,0x0,0x40,0x87,0xfb,0x94,0xf0,0x6,0xb5,0x65,0x87,0xa3,0x8e,0x41,0x49,0x15,
  0x6f,0x5b,0xaa,0xd5,0xf9,0xf2,0x6d,0x4a,0xdc,0xd2,0x27,0x15,0xad,0xd9,0xc1,0xa0,
  0xe7,0xe0,0x51,0x84,0xa0,0x4a,0xe7,0xc2,0x51,0x9a,0x9e,0x81,0xb3,0x2e,0x8d,0xa9,
  0xe1,0x51,0x56,0x64,0x1f,0x1b,0x4d,0x69,0x61,0xab,0x16,0x79,0x2a,0xba,0x8,0x67,
  0x38,0x72,0xe6,0xf9,0xc0,0x70,0x1a,0x99,0x42,0xc6,0x18,0x7a,0xe,0x84,0x2a,0xc3,
  0x21,0xbd,0xe2,0x8a,0x2e,0x23,0xf3,0x83,0xf1,0x54,0xe5,0x92,0x4e,0x49,0x64,0x7f,
  0xa3,0x18,0xe7,0x31,0x73,0xa1,0xf8,0x3a,0x35,0x1,0x34,0x14,0xcf,0x7d,0x1d,0x84,
  0xc4,0x6d,0x3e,0x2d,0x6b,0x2d,0x58,0x28,0x8d,0x84,0xd2,0x95,0xbc,0xa4,0x10,0x9f,
  0x5a,0xc9,0x51,0x23,0x34,0x48,0x4b,0x25,0x14,0xd8,0x59,0xc2,0x67,0x88,0xbf,0xe6,
  0x3,0x61,0xb5,0xd,0x60,0xbf,0xd,0x38,0xfa,0xb,0x2f,0xd1,0x97,0xb3,0x2f,0xa8,
  0x8e,0xa7,0xaa,0xe3,0x18,0xda,0xd5,0x81,0xd2,0xd8,0x55,0x74,0x46,0xe7,0x6b,0xc7,
  0x55,0x17,0x88,0x60,0x2d,0x47,0xbe,0x74,0xb5,0xbf,0x66,0x4,0x19,0x3b,0xe8,0x58,
  0x59,0x74,0x4c,0xf8,0x9c,0x8d,0xb,0x9e,0x9,0x18,0x55,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // imports
  0x0,0x7,
  0x0,0x47,0x69,0x53,
  0x0,0x69,
  0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,0x72,0x0,0x74,0x0,0x73,
    // Qt5Compat
  0x0,0x9,
  0x9,0xa6,0xf6,0x64,
  0x0,0x51,
  0x0,0x74,0x0,0x35,0x0,0x43,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x61,0x0,0x74,
    // GraphicalEffects
  0x0,0x10,
  0x6,0x0,0x28,0xb3,
  0x0,0x47,
  0x0,0x72,0x0,0x61,0x0,0x70,0x0,0x68,0x0,0x69,0x0,0x63,0x0,0x61,0x0,0x6c,0x0,0x45,0x0,0x66,0x0,0x66,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9e,0xc3,0x9,0xfc,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9e,0xc3,0x9,0xfc,0x0,
  // :/qt-project.org/imports
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9e,0xc3,0x9,0xfc,0x0,
  // :/qt-project.org/imports/Qt5Compat
  0x0,0x0,0x0,0x36,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9e,0xc3,0x9,0xfc,0x0,
  // :/qt-project.org/imports/Qt5Compat/GraphicalEffects
  0x0,0x0,0x0,0x4e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9e,0xc3,0x9,0xfc,0x0,
  // :/qt-project.org/imports/Qt5Compat/GraphicalEffects/qmldir
  0x0,0x0,0x0,0x74,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9e,0xc3,0x9,0xfc,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Qt5Compat_GraphicalEffects)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Qt5Compat_GraphicalEffects)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Qt5Compat_GraphicalEffects)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Qt5Compat_GraphicalEffects)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Qt5Compat_GraphicalEffects)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Qt5Compat_GraphicalEffects)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
