/****************************************************************************
** Meta object code from reading C++ file 'qgfxsourceproxy_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../qt5compat/src/imports/graphicaleffects5/private/qgfxsourceproxy_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qgfxsourceproxy_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15QGfxSourceProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto QGfxSourceProxy::qt_create_metaobjectdata<qt_meta_tag_ZN15QGfxSourceProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QGfxSourceProxy",
        "QML.Element",
        "SourceProxy",
        "QML.AddedInVersion",
        "1280",
        "inputChanged",
        "",
        "outputChanged",
        "sourceRectChanged",
        "activeChanged",
        "interpolationChanged",
        "repolish",
        "input",
        "QQuickItem*",
        "output",
        "sourceRect",
        "QRectF",
        "active",
        "interpolation",
        "Interpolation",
        "AnyInterpolation",
        "NearestInterpolation",
        "LinearInterpolation"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'inputChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceRectChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interpolationChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'repolish'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'input'
        QtMocHelpers::PropertyData<QQuickItem*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'output'
        QtMocHelpers::PropertyData<QQuickItem*>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'sourceRect'
        QtMocHelpers::PropertyData<QRectF>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'interpolation'
        QtMocHelpers::PropertyData<enum Interpolation>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Interpolation'
        QtMocHelpers::EnumData<enum Interpolation>(19, 19, QMC::EnumFlags{}).add({
            {   20, Interpolation::AnyInterpolation },
            {   21, Interpolation::NearestInterpolation },
            {   22, Interpolation::LinearInterpolation },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QGfxSourceProxy, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QGfxSourceProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QGfxSourceProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QGfxSourceProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15QGfxSourceProxyE_t>.metaTypes,
    nullptr
} };

void QGfxSourceProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QGfxSourceProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->inputChanged(); break;
        case 1: _t->outputChanged(); break;
        case 2: _t->sourceRectChanged(); break;
        case 3: _t->activeChanged(); break;
        case 4: _t->interpolationChanged(); break;
        case 5: _t->repolish(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QGfxSourceProxy::*)()>(_a, &QGfxSourceProxy::inputChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QGfxSourceProxy::*)()>(_a, &QGfxSourceProxy::outputChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QGfxSourceProxy::*)()>(_a, &QGfxSourceProxy::sourceRectChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QGfxSourceProxy::*)()>(_a, &QGfxSourceProxy::activeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QGfxSourceProxy::*)()>(_a, &QGfxSourceProxy::interpolationChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->input(); break;
        case 1: *reinterpret_cast<QQuickItem**>(_v) = _t->output(); break;
        case 2: *reinterpret_cast<QRectF*>(_v) = _t->sourceRect(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isActive(); break;
        case 4: *reinterpret_cast<enum Interpolation*>(_v) = _t->interpolation(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInput(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 2: _t->setSourceRect(*reinterpret_cast<QRectF*>(_v)); break;
        case 4: _t->setInterpolation(*reinterpret_cast<enum Interpolation*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetInput(); break;
        default: break;
        }
    }
}

const QMetaObject *QGfxSourceProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGfxSourceProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QGfxSourceProxyE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int QGfxSourceProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QGfxSourceProxy::inputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QGfxSourceProxy::outputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QGfxSourceProxy::sourceRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QGfxSourceProxy::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QGfxSourceProxy::interpolationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
